var Color_8h =
[
    [ "Color", "classIMP_1_1display_1_1Color.html", "classIMP_1_1display_1_1Color" ],
    [ "Colors", "Color_8h.html#a77058dfc48162592d6bec3a80a0aa0d9", null ],
    [ "get_display_color", "Color_8h.html#a7139e3c2ffdf998ca304a7f01e6e237e", null ],
    [ "get_gnuplot_color", "Color_8h.html#ad982e4a6182db9aa8157f3fc020da33f", null ],
    [ "get_gray_color", "Color_8h.html#abd278fa3123b329c7fe1784b02f4ca31", null ],
    [ "get_hot_color", "Color_8h.html#ae15042a6bb4f4548ec2876ceddfd3165", null ],
    [ "get_interpolated_rgb", "Color_8h.html#ada2a3156a15dd0217840bfc8675724d8", null ],
    [ "get_jet_color", "Color_8h.html#a8873da49642f951ec86570656e98e908", null ],
    [ "get_linear_color_map_value", "Color_8h.html#af2fb3a798a826b59ab3fb354fe165f69", null ],
    [ "get_rgb_color", "Color_8h.html#a3ea1c11940d14e4ac022768e96514dff", null ]
];